#!/bin/bash

# Test for sudo privileges
if [ "$EUID" -ne 0 ]; then
  echo "The 360Works Linux installer requires elevated privileges, please run it again with sudo."
  exit 1
fi

set -e
cat << "EOF"
          _____  __    ___  __    __           _
         |___ / / /_  / _ \/ / /\ \ \___  _ __| | _____
           |_ \| '_ \| | | \ \/  \/ / _ \| '__| |/ / __|
          ___) | (_) | |_| |\  /\  / (_) | |  |   <\__ \
         |____/ \___/ \___/  \/  \/ \___/|_|  |_|\_\___/
EOF
echo "=============Welcome to the 360Works Linux Installer!=============="
# Tomcat bin directory. Verified via tomcat9.service
TOMCAT_BIN_DIR="/usr/share/tomcat9/bin"

# User preferences directory because we have no other writeable prefs dir.
PREFS_DIR="/var/lib/tomcat_prefs"

# Ensure that the tomcat bin directory exists. Probably want to bail if it doesn't exist, so we don't wreak havoc.
if [ ! -d "$TOMCAT_BIN_DIR" ]; then
  echo "The Tomcat bin directory $TOMCAT_BIN_DIR does not exist. This probably means Tomcat is not installed. Please refer to 'Linux installation instructions.txt' for information on installing necessary packages."
  exit 1
fi

echo "Found Tomcat bin directory at $TOMCAT_BIN_DIR"

echo "Setting up Tomcat"

# Create the setenv.sh file, set JAVA_OPTS, but leave off JDK_JAVA_OPTIONS because it's only used by Java 9 and later.
echo '#!/bin/bash' >"$TOMCAT_BIN_DIR/setenv.sh"
echo 'export JAVA_OPTS="$JAVA_OPTS -Djava.util.prefs.userRoot='$PREFS_DIR' --add-opens java.base/java.net=ALL-UNNAMED --add-opens java.base/jdk.internal.loader=ALL-UNNAMED --add-opens java.logging/java.util.logging=ALL-UNNAMED --add-opens java.base/sun.net.www.http=ALL-UNNAMED --add-opens java.base/sun.security.ssl=ALL-UNNAMED --add-opens java.base/java.io=ALL-UNNAMED --add-exports java.base/sun.net.www.protocol.https=ALL-UNNAMED --add-exports java.base/sun.net.www.protocol.http=ALL-UNNAMED --add-exports java.xml/com.sun.org.apache.xml.internal.serialize=ALL-UNNAMED"' >>"$TOMCAT_BIN_DIR/setenv.sh"

# Make the script executable
chmod +x "$TOMCAT_BIN_DIR/setenv.sh"

echo "Creating 360Works preferences directory"

# Create the preferences directory and set the owner to tomcat
mkdir -p "$PREFS_DIR"
chown tomcat:tomcat "$PREFS_DIR"

echo "Making sure Tomcat is ready"

arch=$(uname -m)
if [ "$arch" = "aarch64" ]; then
  arch="arm64"
fi
if [ "$arch" = "x86_64" ]; then
  arch="amd64"
fi
java_home="JAVA_HOME=/usr/lib/jvm/java-17-openjdk-$arch"
#First, remove any existing instance of this line... (using # instead of / for the sed delimiter since the path has / in it)
sudo sed -i "s#$java_home##g" /etc/default/tomcat9
#Now re-add the line to the top of the file
sudo sed -i "1i$java_home" /etc/default/tomcat9
#reload the daemon (I've seen it required before).
sudo systemctl daemon-reload
#restart tomcat
sudo service tomcat9 restart

cd Installer\ data
sudo java -XX:+IgnoreUnrecognizedVMOptions --add-opens java.base/java.lang=ALL-UNNAMED -jar installer.jar headlessInstall install
# Try without final restart, the installer may restart tomcat for us..
# sudo service tomcat9 restart
